qualpipe 0.3.0 (2026-04-02)
---------------------------


API Changes
~~~~~~~~~~~

- Refactor ``MetricEvaluator`` and ``Metric`` I/O based on ``data_category``:

  - Event tables (``DL1_EVENT``, ``DL0_EVENT``): read directly via
    ``ctapipe.io.read_table`` with ``input_source`` as ``<table_path>/<column>``;
    timestamps are joined from the subarray trigger table when not present in the
    data table.
  - Monitoring tables (``DL1_MONITORING``): retrieved via
    ``ctapipe.io.MonitoringSource.get_table()``.
  - New optional ``input_source_subtype`` trait added to ``Metric`` for data
    sources that require a subtype parameter (e.g. ``PIXEL_STATISTICS``
    monitoring data).

  .. note::

     ``data_category`` is now a trait of ``MetricEvaluator``, not of individual
     ``Metric`` instances. All metrics in a single run must therefore share the
     same data category, and only one input file can be processed per
     ``MetricEvaluator`` invocation. [`!40 <https://gitlab.cta-observatory.org/cta-computing/dpps/qualpipe/qualpipe/-/merge_requests/40>`__]


Bug Fixes
~~~~~~~~~

- Fix default values in configuration for criteria and metric evaluator [`!39 <https://gitlab.cta-observatory.org/cta-computing/dpps/qualpipe/qualpipe/-/merge_requests/39>`__]


New Features
~~~~~~~~~~~~

- Introduce time/n_event-dependent criteria applications, add TrivialDescriptor and update the descriptors with the new chunking strategy. [`!37 <https://gitlab.cta-observatory.org/cta-computing/dpps/qualpipe/qualpipe/-/merge_requests/37>`__]

- Added CWL workflow test bench and one workflow for evaluating metrics for camera calibration. [`!42 <https://gitlab.cta-observatory.org/cta-computing/dpps/qualpipe/qualpipe/-/merge_requests/42>`__]


Maintenance
~~~~~~~~~~~


Refactoring and Optimization
~~~~~~~~~~~~~~~~~~~~~~~~~~~~

qualpipe 0.0.1 (2024-11-05)
--------------------------------


API Changes
~~~~~~~~~~~


Bug Fixes
~~~~~~~~~


New Features
~~~~~~~~~~~~


Maintenance
~~~~~~~~~~~


Refactoring and Optimization
~~~~~~~~~~~~~~~~~~~~~~~~~~~~
